@@ -8,7 +8,9 @@ def Chart(
         class_name=None,
         data=None,
         height=400,
+        name=None,
         options=None,
+        period_days_select=None,
         series=None,
         style=None,
         title=None,
@@ -21,7 +23,9 @@ def Chart(
             "className": class_name,
             "data": data,
             "height": height,
+            "name": name,
             "options": options,
+            "periodDaysSelect": period_days_select,
             "series": series,
             "style": style,
             "title": title,
